@@ -1,4 +1,4 @@
-#! /usr/bin/env python2.7
+#!/usr/bin/env python2.7
 
 """This is a much simpler version of the aliens.py
 example. It makes a good place for beginners to get
@@ -18,7 +18,7 @@ import pygame
 from pygame.locals import *
 
 if not pygame.image.get_extended():
-    raise SystemExit, "Requires the extended image loading from SDL_image"
+    raise SystemExit("Requires the extended image loading from SDL_image")
 
 
 #constants
@@ -36,18 +36,19 @@ SCREENRECT     = Rect(0, 0, 640, 480)
 dirtyrects = [] # list of update_rects
 next_tick = 0   # used for timing
 class Img: pass # container for images
-
+main_dir = os.path.split(os.path.abspath(__file__))[0]  # Program's diretory
 
 
 #first, we define some utility functions
     
 def load_image(file, transparent):
     "loads an image, prepares it for play"
-    file = os.path.join('data', file)
+    file = os.path.join(main_dir, 'data', file)
     try:
         surface = pygame.image.load(file)
     except pygame.error:
-        raise SystemExit, 'Could not load image "%s" %s'%(file, pygame.get_error())
+        raise SystemExit('Could not load image "%s" %s' %
+                         (file, pygame.get_error()))
     if transparent:
         corner = surface.get_at((0, 0))
         surface.set_colorkey(corner, RLEACCEL)
@@ -233,4 +234,4 @@ def main():
 #if python says run, let's run!
 if __name__ == '__main__':
     main()
-    
\ No newline at end of file
+    
