@@ -1,15 +1,17 @@
-#!/usr/bin/env python2.6
+#!/usr/bin/env python2.7
 """
 Creates an echo effect an any Sound object.
 
-Uses sndarray and Numeric to create offset faded copies of the
+Uses sndarray and MumPy ( or Numeric) to create offset faded copies of the
 original sound. Currently it just uses hardcoded values for the
 number of echos and the delay. Easy for you to recreate as 
-needed.
+needed. The array packaged used can be specified by an optional
+--numpy or --numeric command line option.
 
 version 2. changes:
 - Should work with different sample rates now.
 - put into a function.
+- Uses NumPy by default, but falls back on Numeric.
 
 """
 
@@ -19,15 +21,15 @@ __license__ = "Public Domain"
 __version__ = "2.0"
 
 
+import sys
 import os.path
 import pygame.mixer, pygame.time, pygame.sndarray, pygame
 import pygame.surfarray, pygame.transform
+from pygame import sndarray, mixer
 
-mixer = pygame.mixer
-sndarray = pygame.sndarray
 import time
 from math import sin
-from Numeric import *
+
 
 #mixer.init(44100, -16, 0)
 mixer.init()
@@ -47,12 +49,12 @@ def make_echo(sound, samples_per_second,  mydebug = True):
 
     a1 = sndarray.array(sound)
     if mydebug:
-        print 'SHAPE1:', a1.shape
+        print ('SHAPE1: %s' % (a1.shape,))
 
     length = a1.shape[0]
 
     #myarr = zeros(length+12000)
-    myarr = zeros(a1.shape)
+    myarr = zeros(a1.shape, int32)
 
     if len(a1.shape) > 1:
         mult = a1.shape[1]
@@ -64,20 +66,20 @@ def make_echo(sound, samples_per_second,  mydebug = True):
         #size = (a1.shape[0] + int(a1.shape[0] + (echo_length * 3000)),)
 
     if mydebug:
-        print int(echo_length * a1.shape[0])
-    myarr = zeros(size)
+        print (int(echo_length * a1.shape[0]))
+    myarr = zeros(size, int32)
 
 
 
     if mydebug:
-        print "size", size
-        print myarr.shape
+        print ("size %s" % (size,))
+        print (myarr.shape)
     myarr[:length] = a1
-    #print myarr[3000:length+3000]
-    #print a1 >> 1
-    #print "a1.shape", a1.shape
+    #print (myarr[3000:length+3000])
+    #print (a1 >> 1)
+    #print ("a1.shape %s" % (a1.shape,))
     #c = myarr[3000:length+(3000*mult)]
-    #print "c.shape", c.shape
+    #print ("c.shape %s" % (c.shape,))
 
     incr = int(samples_per_second / echo_length)
     gap = length
@@ -89,10 +91,10 @@ def make_echo(sound, samples_per_second,  mydebug = True):
     myarr[incr*4:gap+(incr*4)] += a1>>4
 
     if mydebug:
-        print 'SHAPE2:', myarr.shape
+        print ('SHAPE2: %s' % (myarr.shape,))
 
 
-    sound2 = sndarray.make_sound(myarr.astype(Int16))
+    sound2 = sndarray.make_sound(myarr.astype(int16))
 
     return sound2
 
@@ -102,7 +104,7 @@ def slow_down_sound(sound, rate):
            rate - at which the sound should be slowed down.  eg. 0.5 would be half speed.
     """
 
-    raise NotImplementedError
+    raise NotImplementedError()
     grow_rate = 1 / rate
 
     # make it 1/rate times longer.
@@ -110,16 +112,16 @@ def slow_down_sound(sound, rate):
     a1 = sndarray.array(sound)
 
     surf = pygame.surfarray.make_surface(a1)
-    print a1.shape[0] * grow_rate
+    print (a1.shape[0] * grow_rate)
     scaled_surf = pygame.transform.scale(surf, (int(a1.shape[0] * grow_rate), a1.shape[1]))
-    print scaled_surf
-    print surf
+    print (scaled_surf)
+    print (surf)
 
     a2 = a1 * rate
-    print a1.shape
-    print a2.shape
-    print a2
-    sound2 = sndarray.make_sound(a2.astype(Int16))
+    print (a1.shape)
+    print (a2.shape)
+    print (a2)
+    sound2 = sndarray.make_sound(a2.astype(int16))
     return sound2
 
 
@@ -156,53 +158,79 @@ def sound_from_pos(sound, start_pos, samples_per_second = None, inplace = 1):
 
 
 
-if __name__ == "__main__":
+def main(arraytype=None):
+    """play various sndarray effects
 
-    import sys
+    If arraytype is provided then use that array package. Valid
+    values are 'numeric' or 'numpy'. Otherwise default to NumPy,
+    or fall back on Numeric if NumPy is not installed.
 
-    print "mixer.get_init", mixer.get_init()
+    """
+
+    global zeros, int16, int32
+
+    main_dir = os.path.split(os.path.abspath(__file__))[0]
+    
+    if arraytype is None:
+        if 'numpy' in sndarray.get_arraytypes():
+            sndarray.use_arraytype('numpy')
+        elif 'numeric' in sndarray.get_arraytype():
+            sndarray.use_arraytype('numeric')
+        else:
+            raise ImportError('No array package is installed')
+    else:
+        sndarray.use_arraytype(arraytype)
+    pygame.surfarray.use_arraytype(sndarray.get_arraytype())
+
+    if sndarray.get_arraytype() == 'numpy':
+        from numpy import zeros, int16, int32
+    else:
+        from Numeric import zeros, Int16 as int16, Int32 as int32
+
+    print ("Using %s array package" % sndarray.get_arraytype())
+    print ("mixer.get_init %s" % (mixer.get_init(),))
     inited = mixer.get_init()
 
     samples_per_second = pygame.mixer.get_init()[0]
 
     
 
-    print ("-" * 30) + "\n"
-    print "loading sound"
-    sound = mixer.Sound(os.path.join('data', 'car_door.wav'))
+    print (("-" * 30) + "\n")
+    print ("loading sound")
+    sound = mixer.Sound(os.path.join(main_dir, 'data', 'car_door.wav'))
 
 
 
-    print "-" * 30
-    print "start positions"
-    print "-" * 30
+    print ("-" * 30)
+    print ("start positions")
+    print ("-" * 30)
 
     start_pos = 0.1
     sound2 = sound_from_pos(sound, start_pos, samples_per_second)
 
-    print "sound.get_length", sound.get_length()
-    print "sound2.get_length", sound2.get_length()
+    print ("sound.get_length %s" % (sound.get_length(),))
+    print ("sound2.get_length %s" % (sound2.get_length(),))
     sound2.play()
     while mixer.get_busy():
         pygame.time.wait(200)
 
-    print "waiting 2 seconds"
+    print ("waiting 2 seconds")
     pygame.time.wait(2000)
-    print "playing original sound"
+    print ("playing original sound")
 
     sound.play()
     while mixer.get_busy():
         pygame.time.wait(200)
 
-    print "waiting 2 seconds"
+    print ("waiting 2 seconds")
     pygame.time.wait(2000)
 
 
 
     if 0:
         #TODO: this is broken.
-        print ("-" * 30) + "\n"
-        print "Slow down the original sound."
+        print (("-" * 30) + "\n")
+        print ("Slow down the original sound.")
         rate = 0.2
         slowed_sound = slow_down_sound(sound, rate)
 
@@ -211,45 +239,61 @@ if __name__ == "__main__":
             pygame.time.wait(200)
 
 
-    print "-" * 30
-    print "echoing"
-    print "-" * 30
+    print ("-" * 30)
+    print ("echoing")
+    print ("-" * 30)
 
     t1 = time.time()
     sound2 = make_echo(sound, samples_per_second)
-    print "time to make echo", time.time() - t1
+    print ("time to make echo %i" % (time.time() - t1,))
 
 
-    print "original sound"
+    print ("original sound")
     sound.play()
     while mixer.get_busy():
         pygame.time.wait(200)
 
-    print "echoed sound"
+    print ("echoed sound")
     sound2.play()
     while mixer.get_busy():
         pygame.time.wait(200)
 
 
-    sound = mixer.Sound(os.path.join('data', 'secosmic_lo.wav'))
+    sound = mixer.Sound(os.path.join(main_dir, 'data', 'secosmic_lo.wav'))
 
     t1 = time.time()
     sound3 = make_echo(sound, samples_per_second)
-    print "time to make echo", time.time() - t1
+    print ("time to make echo %i" % (time.time() - t1,))
 
-    print "original sound"
+    print ("original sound")
     sound.play()
     while mixer.get_busy():
         pygame.time.wait(200)
 
 
-    print "echoed sound"
+    print ("echoed sound")
     sound3.play()
     while mixer.get_busy():
         pygame.time.wait(200)
 
 
+def usage():
+    print ("Usage: command line option [--numpy|--numeric]")
+    print ("  The default is to use NumPy if installed,")
+    print ("  otherwise Numeric")
 
+if __name__ == '__main__':
+    if len(sys.argv) == 2:
+        if '--numpy' in sys.argv:
+            main('numpy')
+        elif '--numeric' in sys.argv:
+            main('numeric')
+        else:
+            usage()
+    elif len(sys.argv) == 1:
+        main()
+    else:
+        usage()
 
 
 
